"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseExpressionBuilder = void 0;
exports.validatePagination = validatePagination;
const DynamoValidationError_1 = require("@denis_bruns/foundation/dist/types/errors/DynamoValidationError");
class BaseExpressionBuilder {
    pkName;
    constructor(pkName = "id") {
        this.pkName = pkName;
    }
    extractPartitionKeyFilter(filters) {
        const remaining = [...filters];
        const pkIndex = remaining.findIndex((f) => f.field === this.pkName && f.operator === "=");
        if (pkIndex === -1) {
            return { remainingFilters: remaining };
        }
        const pkFilter = remaining[pkIndex];
        remaining.splice(pkIndex, 1);
        return { pkFilter, remainingFilters: remaining };
    }
}
exports.BaseExpressionBuilder = BaseExpressionBuilder;
function validatePagination(pagination = {}) {
    if (!pagination) {
        pagination = {};
    }
    const { page = 1, size = 10, limit, offset = 0 } = pagination;
    if (page !== undefined && !Number.isInteger(Number(page))) {
        throw new DynamoValidationError_1.DynamoValidationError('Page must be an integer');
    }
    if (size !== undefined && !Number.isInteger(Number(size))) {
        throw new DynamoValidationError_1.DynamoValidationError('Size must be an integer');
    }
    if (limit !== undefined && !Number.isInteger(Number(limit))) {
        throw new DynamoValidationError_1.DynamoValidationError('Limit must be an integer');
    }
    if (offset !== undefined && !Number.isInteger(Number(offset))) {
        throw new DynamoValidationError_1.DynamoValidationError('Offset must be an integer');
    }
}
//# sourceMappingURL=BaseExpressionBuilder.js.map